@@ -13,6 +13,8 @@ colormap_names = [
 
 
 def by_name(colormap_name, return_rgb=True):
+    if colormap_name is None:
+        return None
     cmn = colormap_name.lower()
     if cmn == 'gray' or cmn == 'grayscale' or cmn == 'grey' or cmn == 'greyscale':
         return colormap_gray
@@ -22,6 +24,26 @@ def by_name(colormap_name, return_rgb=True):
         )]
 
 
+def sample(colormap_name, N, return_rgb=True):
+    """Returns N uniformly spread colors from the given colormap (specified by its name).
+    For example, to sample 10 uniformly spaced colors from HSV: colors = sample('hsv', 10)
+    If N > len(colormap), the colormap entries will be repeated.
+    """
+    cmap = by_name(colormap_name, return_rgb=return_rgb)
+    if N < 2:
+        raise ValueError('N must be > 1')
+
+    if N <= len(cmap):
+        # Truncate indices to get our intended behavior (e.g. 3 entries yields #0, #127, #255)
+        indices = np.floor(np.linspace(0, len(cmap)-1, num=min(len(cmap), N), endpoint=True)).astype(np.int)
+        return [cmap[idx] for idx in indices]
+    else:
+        # Repeat the colormap as often as needed
+        reps = int(N / len(cmap))
+        rem = N % len(cmap)
+        return cmap*reps + cmap[0:rem]
+
+
 def make_flow_color_wheel():
     """Returns the standard color wheel (i.e. a 55x3 color map) used for
     optical flow visualization. This is a port of the C++/MATLAB code from
